/**
 * PETALS - PETALS Services Platform. Copyright (c) 2009 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * ------------------------------------------------------------------------- $Id
 * : $ -------------------------------------------------------------------------
 */

package org.ow2.petals.se.quartz.job;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.jbi.messaging.MessagingException;

import org.ow2.petals.component.framework.api.Message.MEPConstants;
import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;
import org.ow2.petals.component.framework.api.exception.PEtALSCDKException;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.jbidescriptor.generated.Consumes;
import org.ow2.petals.component.framework.util.UtilFactory;
import org.ow2.petals.se.quartz.Constants;
import org.ow2.petals.se.quartz.QuartzUtils;
import org.ow2.petals.se.quartz.SchedulerManager;
import org.quartz.Job;
import org.quartz.JobDataMap;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

/**
 * @version $Rev: $ $Date: $
 * @author Adrien LOUIS - EBMWebSourcing
 */
public class EmitSignalJob implements Job {

    /*
     * (non-Javadoc)
     * @see org.quartz.Job#execute(org.quartz.JobExecutionContext)
     */
    public void execute(final JobExecutionContext jobContext) throws JobExecutionException {
        final JobDataMap dataMap = jobContext.getJobDetail().getJobDataMap();
        final SchedulerManager schedulerManager = (SchedulerManager) dataMap
        .get(Constants.SCHEDULER_MANAGER);
        final Consumes consume = schedulerManager.getConsumes();
        final ConfigurationExtensions extensions = new ConfigurationExtensions(consume.getAny());
        final Logger logger = schedulerManager.getLogger();

        try {
            final Exchange exchange = schedulerManager.createConsumeExchange(consume,
                    MEPConstants.IN_ONLY_PATTERN);
            final String content = extensions.get(Constants.CONTENT_EXPRESSION);
            if (logger.isLoggable(Level.FINEST)) {
                logger.finest("create an exchange to call "
                        + QuartzUtils.generateServiceName(exchange));
                logger.finest("content to send is : " + content);
            }
            exchange.getInMessage().setContent(UtilFactory.getSourceUtil().createSource(content));
            schedulerManager.send(exchange);
        } catch (final MessagingException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        } catch (final PEtALSCDKException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        }
    }
}
